@@ -2,7 +2,8 @@ import os
 import numpy as np
 from os.path import join
 from astropy.io.fits import Header
-from .. import open as pyregion_open
+
+from pyregion import open as pyregion_open
 
 rootdir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
 
